#include "person.h"

#include <fstream>    // std::ifstream
#include <iostream>   // std::cout
#include <string>     // std::getline, std::string

// call as: ./input-from-file <filename>
//
int main(int argc, char** argv)
{
   if(argc < 2)
   {
      std::cout << "Command-line argument missing.\n";
      return EXIT_FAILURE;  // indicates to OS that the program failed
   }
   
   std::ifstream file_in(argv[1]);
   if(!file_in)
   {
      std::cout << "File '" << argv[1] << "' could not be opened.\n\n";
      return EXIT_FAILURE;
   }
   
   // read number of entries (first data item in file)
   //
   int N = 0;
   file_in >> N;
   
   // ignore the rest of the line, which might be a comment
   //
   std::string skip;
   std::getline(file_in, skip);
   
   // allocate memory for N persons
   //
   Person* person_register = new Person[N]{};
   
   // read the individual entries from the file
   //
   for(int i = 0; i < N; i++)
      person_register[i].read_from_stream(&file_in);

   // close the file stream once we are done with reading
   //
   file_in.close();

   // validate by writing the information back to standard output
   //
   for(int i = 0; i < N; i++)
      person_register[i].write_to_stream(&std::cout);
   
   // deallocate the array: For every new, there must be a delete
   // pay attention that arrays must be allocated with "delete[]"
   //
   delete[] person_register;
}
